"""This library developed by searchunify. This library has various capabilities data pulling and pushing. This library gives the simple way to integrate SearchUnify API's"""
__author__ = "Mohan Rana"
__copyright__ = "Copyright 2021, SearchUnify"
__version__ = "1.0.1"
__maintainer__ = "SearchUnify"
__email__ = "mohanr@grazitti.com"

from searchunify.main import Searchunify